#
# spec file for package dqlite
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2024 Andreas Stieger <Andreas.Stieger@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname libdqlite0
Name:           dqlite
Version:        1.18.0
Release:        1.1
Summary:        Distributed SQLite
License:        LGPL-3.0-only WITH LGPL-3.0-linking-exception
Group:          Development/Libraries/C and C++
URL:            https://github.com/canonical/dqlite
Source:         https://github.com/canonical/dqlite/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  pkgconfig >= 0.9.0
BuildRequires:  pkgconfig(liblz4) >= 1.7.1
BuildRequires:  pkgconfig(libuv) >= 1.8.0
BuildRequires:  pkgconfig(sqlite3) >= 3.22.0

%description
dqlite is a C library implementing an embeddable and replicated
SQL database engine with high-availability and automatic failover.

%package -n %{lname}
Summary:        Library implementing the distributed SQLite
Group:          System/Libraries

%description -n %{lname}
dqlite is a C library implementing an embeddable and replicated
SQL database engine with high-availability and automatic failover.

dqlite extends SQLite with a network protocol that can connect
together various instances of an application and have them act as a
highly-availablity cluster.

%package devel
Summary:        Development files for the distributed SQLite
Group:          Development/Libraries/C and C++
Requires:       %{lname} = %{version}

%description devel
dqlite is a C library implementing an embeddable and replicated
SQL database engine with high-availability and automatic failover.

This package contains the files necessary for developing and building
applications using the library.

%prep
%autosetup -p1

%build
autoreconf -fiv
%configure \
	--disable-static \
	--enable-build-raft \
	%{nil}
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%ldconfig_scriptlets -n %{lname}

%check
make check %{?_smp_mflags}

%files devel
%license LICENSE
%doc AUTHORS README.md
%{_includedir}/dqlite.h
%{_libdir}/libdqlite.so
%{_libdir}/pkgconfig/dqlite.pc

%files -n %{lname}
%license LICENSE
%{_libdir}/libdqlite.so.*

%changelog
* Mon Jun  2 2025 Andrea Manzini <andrea.manzini@suse.com>
- update to 1.18.0:
  * new development release, no significant changes from 1.17.2 LTS
- added %%check section to run tests at build
* Sat Mar  8 2025 Andrea Manzini <andrea.manzini@suse.com>
- update to 1.17.2:
  * In replication scenario, entry_sm gets updated every time it is used
  * Add an API for querying the last raft log entry
  * Fix the build when liblz4 is missing and test it
  * Propagate raft_recover errors and improve tracing
  * Remove option to link separately-built libraft
  * Remove dqlite-next build configuration
  * Start instrumenting existing code with state machines
  * Snapshot checkpointing
  * Refactor leader.c to fix stack growth in handle_exec_sql
  * Fix frames leak when VfsPoll fails
* Tue Aug  6 2024 Andreas Stieger <andreas.stieger@gmx.de>
- update to 1.16.7:
  * Fix a possible UAF
  * bugfix: reading segment, correctly stop on error
  * Cleanup prepared statement during node close
  * now uses file locking to ensure that two nodes don't run
    concurrently using the same data directory
* Wed Feb 28 2024 Andreas Stieger <andreas.stieger@gmx.de>
- update to 1.16.4:
  * build system fixes
* Wed Feb 21 2024 Andreas Stieger <andreas.stieger@gmx.de>
- update to 1.16.3:
  * canonical/raft is now a private implementation detail of dqlite
    canonical/raft will no longer be updated, replaced by
    cowsql/raft fork
  * Fix many cases of arithmetic on void pointers
* Mon Feb 19 2024 Andreas Stieger <andreas.stieger@gmx.de>
- update to 1.16.2:
  * fix for using dqlite with SQLite versions greater than 3.45.0
  * A more readable logging format
  * internal improvement to how dqlite reacts to Raft state changes
  * new dqlite_node configuration option to control snapshot
    compression
* Mon Nov  6 2023 Andreas Stieger <andreas.stieger@gmx.de>
- Update to 1.16.0:
  * expose one new API, dqlite_node_set_auto_recovery
* Tue Jun 27 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 1.15.1:
  * Various bug fixes to help dqlite correctly handle large databases (#459, #460)
  * Fixes and cleanup for the internal dqlite client API (#458)
  * Fixes and cleanup for dqlite's handling of client connections (#476)
  * Support for SQL queries that both modify the database and return rows,
    using the QUERY and QUERY_SQL requests (#477)
  * Support for server-side cluster role management (#480)
* Sat Jan 28 2023 Andreas Stieger <andreas.stieger@gmx.de>
- disable tests timing out in obs
* Fri Jan 20 2023 Andreas Stieger <andreas.stieger@gmx.de>
- update to 1.14.0:
  * compatibility with libraft 0.17.1
* Tue Dec 27 2022 Andreas Stieger <andreas.stieger@gmx.de>
- update to 1.13.0:
  * experimental disk-mode
  * Fix an issue that limited maximum row size
* Sun Dec  4 2022 Andreas Stieger <andreas.stieger@gmx.de>
- update to 1.12.0:
  * support more than 255 statement parameters
  * requires libraft 0.16.0
* Sat Jul 23 2022 Andreas Stieger <andreas.stieger@gmx.de>
- update to 1.11.1:
  * Replace deprecated raft function raft_fixture_init with
    raft_fixture_initialize
- includes changes from 1.11.0:
  * Fix a bug that causes a node to crash under certain conditions
    after losing leadership in the middle of a transaction
* Tue Apr 19 2022 Andreas Stieger <andreas.stieger@gmx.de>
- update to 1.10.0:
  * raft snapshots no longer copy the whole database, but the WAL
    for a smaller size
* Sun Mar 13 2022 Andreas Stieger <andreas.stieger@gmx.de>
- update to 1.9.1:
  * Detailed tracing will be enabled when the environment variable
    LIBDQLITE_TRACE is set before startup
- remove explicit devel package requirements for private libs
- remove conditional build dependencies for mandatory dependencies
- run tests
- update license specification
* Thu Aug  5 2021 jenting hsiao <jenting.hsiao@suse.com>
- Updates to version v1.9.0
  * Added dqlite_node_set_network_latency_ms which deprecates the old dqlite_node_set_network_latency.
  * Added dqlite_node_recover_ext which deprecates the old dqlite_node_recover and takes node roles into account.
* Thu Jun 10 2021 jenting hsiao <jenting.hsiao@suse.com>
- Updates to version v1.8.0
  * Expose raft snapshot settings through dqlite_node_set_snapshot_params.
  * Add DQLITE_VERSION_XXXXX macros to perform feature detection.
* Thu Apr 29 2021 jenting hsiao <jenting.hsiao@suse.com>
- Updates to version v1.7.0
  * Lowering of default HeartBeat timeout
  * Multi platform fixes
  * Various bugfixes
* Fri Oct 30 2020 Jan Engelhardt <jengelh@inai.de>
- Trim and wrap descriptions. Clear double-shipping of
  documentation.
* Thu Oct 29 2020 jenting hsiao <jenting.hsiao@suse.com>
- initial dqlite package, version v1.6.0
